diff --git a/nodejs-tests/assets/isAntialiased/diffWithCustomTolerance.png b/nodejs-tests/assets/isAntialiased/diffWithCustomTolerance.png
new file mode 100644
index 0000000..856300b
Binary files /dev/null and b/nodejs-tests/assets/isAntialiased/diffWithCustomTolerance.png differ
diff --git a/nodejs-tests/assets/square1.png b/nodejs-tests/assets/square1.png
new file mode 100644
index 0000000..32bfe79
Binary files /dev/null and b/nodejs-tests/assets/square1.png differ
diff --git a/nodejs-tests/assets/square2.png b/nodejs-tests/assets/square2.png
new file mode 100644
index 0000000..18dfa4b
Binary files /dev/null and b/nodejs-tests/assets/square2.png differ
diff --git a/nodejs-tests/ignore.test.js b/nodejs-tests/ignore.test.js
index 3ac51b7..5911c5a 100644
--- a/nodejs-tests/ignore.test.js
+++ b/nodejs-tests/ignore.test.js
@@ -25,6 +25,34 @@ describe("ignore", () => {
         });
     });
 
+    test("ignore antialiasing on with custom tolerance", async () => {
+        const text = fs.readFileSync("./nodejs-tests/assets/square1.png");
+        const textAa = fs.readFileSync("./nodejs-tests/assets/square2.png");
+
+        return new Promise((resolve) => {
+            const opts = {
+                ignore: "antialiasing",
+                tolerance: {
+                    red: 16,
+                    green: 16,
+                    blue: 16
+                }
+            };
+
+            resemble.compare(text, textAa, opts, async (_x, data) => {
+                expect(data.misMatchPercentage).toBe("100.00");
+                const buffer = data.getBuffer();
+
+                expect(buffer).toBeInstanceOf(Buffer);
+
+                const comparison = fs.readFileSync("./nodejs-tests/assets/isAntialiased/diffWithCustomTolerance.png");
+
+                expect(buffer.equals(comparison)).toBe(true);
+                resolve();
+            });
+        });
+    });
+
     test("ignore antialiasing off", async () => {
         const text = fs.readFileSync("./nodejs-tests/assets/text.png");
         const textAa = fs.readFileSync("./nodejs-tests/assets/textAa.png");
diff --git a/output.png b/output.png
new file mode 100644
index 0000000..856300b
Binary files /dev/null and b/output.png differ
diff --git a/resemble.js b/resemble.js
index a913d23..4e57f11 100644
--- a/resemble.js
+++ b/resemble.js
@@ -960,6 +960,15 @@ var isNode = function () {
                     wrapper();
 
                     return getCompareApi(wrapper);
+                },
+                setupCustomTolerance: function (customSettings) {
+                    for (var property in tolerance) {
+                        if (!customSettings.hasOwnProperty(property)) {
+                            continue;
+                        }
+
+                        tolerance[property] = customSettings[property];
+                    }
                 }
             };
 
@@ -990,7 +999,7 @@ var isNode = function () {
         return resemble;
     }
 
-    function applyIgnore(api, ignore) {
+    function applyIgnore(api, ignore, customTolerance) {
         switch (ignore) {
             case "nothing":
                 api.ignoreNothing();
@@ -1010,6 +1019,8 @@ var isNode = function () {
             default:
                 throw new Error("Invalid ignore: " + ignore);
         }
+
+        api.setupCustomTolerance(customTolerance);
     }
 
     resemble.compare = function (image1, image2, options, cb) {
@@ -1041,11 +1052,12 @@ var isNode = function () {
             compare.scaleToSameSize();
         }
 
+        var toleranceSettings = opt.tolerance || {};
         if (typeof opt.ignore === "string") {
-            applyIgnore(compare, opt.ignore);
+            applyIgnore(compare, opt.ignore, toleranceSettings);
         } else if (opt.ignore && opt.ignore.forEach) {
             opt.ignore.forEach(function (v) {
-                applyIgnore(compare, v);
+                applyIgnore(compare, v, toleranceSettings);
             });
         }
 
